#
# spec file for package atomix
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           atomix
Version:        44.0
Release:        1.5
Summary:        A puzzle game where you move atoms to build a molecule
License:        GPL-2.0-or-later
Group:          Amusements/Games/Board/Other
URL:            https://wiki.gnome.org/Apps/Atomix
Source0:        https://download.gnome.org/sources/atomix/44/%{name}-%{version}.tar.xz

BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.0.5
BuildRequires:  pkgconfig(glib-2.0) >= 2.36.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.14.0
BuildRequires:  pkgconfig(libgnome-games-support-1)

%description
You start the game with the map filled with walls and a few atoms, which you can
move in any direction. However, the atoms won't stop until they hit a wall or
another atom.

You can see a preview of what molecule you have to build, and you have to do your
best to find where to build the molecule, and move the atoms there.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name}

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/metainfo/atomix.appdata.xml
%{_datadir}/applications/atomix.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*

%files lang -f %{name}.lang

%changelog
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Stable release version bump.
* Mon Mar  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Fixed build issues.
  + Updated translations.
- Drop atomix-gcc10.patch: fixed upstream.
* Thu Jun  4 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add atomix-gcc10.patch: Fix build with GCC 10.
* Tue Sep 10 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Stable release version bump.
* Fri Sep  6 2019 mgorse@suse.com
- Update to version 3.33.92:
  + Updated translations.
* Wed Aug 14 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Fixed keys in menu controlling game.
  + Fixed keyboard shortcuts.
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Stable release version bump.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Updated translations.
* Sun Feb 17 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Moved app menu to in-game menu.
  + Removed quit menu item.
  + Updated translations.
* Sun Sep  9 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0.1:
  + Fixed game menu not appearing (glgo#GNOME/atomix#13).
- Changes from version 3.30.0:
  + Do not show scores after entering scores.
  + Fixed libgnome-games-support git repo typo.
  + Updated translations.
- Remove lang package from recommended packages as it already
  supplements main package (same effect, it's redundant).
* Tue Jun 19 2018 bjorn.lie@gmail.com
- Update to version 3.29.3:
  + Implemented appmenu (glgo#GNOME/atomix#7).
  + Handle highscores using libgnome-games-support
    (glgo#GNOME/atomix#6).
  + Add flatpak manifest (glgo#GNOME/atomix#11).
  + Port to Meson.
  + Level names made translatable.
  + Migrated to gettext.
  + Updated bugzilla references to gitlab.
- Add meson BuildRequires and corresponding macros following
  upstreams port to meson buildsystem.
- Add pkgconfig(libgnome-games-support-1) BuildRequires: New
  dependency.
- Drop intltool BuildRequires: No longer needed, nor used.
- Use autosetup macro.
- Drop post(un) handling of icon_theme_cache_post(un), no longer
  needed on current versions of openSUSE.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Added content ratings.
  + Updated translations.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Updated translations.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Port from gnome-common.
  + Fix compilation warnings.
  + Updated translations.
* Tue Aug 16 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Use label word wrap instead of newlines.
  + Updated translations.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + No changes.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + New icon and logo for GNOME3.
  + Symbolic and low-res icon.
  + Updated translations.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Updated Appdata to spec version 0.7.
  + Added tag to Appdata.
  + Updated translations.
* Tue Jan 19 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Added scalable icon (bgo#746471).
  + Use new icon and GtkApplication (bgo#742871).
  + Single-instance application.
  + Remove window border.
  + Register window actions.
  + Fixed autogen deprecation warnings.
  + Updated translations.
- Add %%icon_theme_cache_post/%%icon_theme_cache_postun macros to
  post/postun scripts in order to rebuild the icon cache.
* Tue Dec 22 2015 zaitor@opensuse.org
- Update to version 3.19.3:
  + Updated translations.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + Show gameplay tips (bgo#587868).
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + No changes, stable version.
* Mon Sep 14 2015 zaitor@opensuse.org
- Update to version 3.17.92:
  + Updated translations.
* Tue Sep  1 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Fixed about dialog not showing close button.
  + Website on about dialog should not be translatable.
  + Updated translations.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Updated translations.
- Drop pkgconfig(libxml2) BuildRequires: No longer needed.
* Wed Jun 24 2015 dimstar@opensuse.org
- Own %%{_datadir}/appdata.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Fixed licensing mistake in appdata (bgo#746473).
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Initial package, version 3.15.91.
